@@ -3,18 +3,25 @@ gcalendar <- function(text = "", format = "%Y-%m-%d",
 
 
     widget <- EXTComponent$new(toplevel=container$toplevel,
-                               ..text = text,
                                ..format = format)
     class(widget) <- c("gCalendar",class(widget))
 
-    ## XXX put in today's date?
-    widget$setValue(value="")           # no day
+    widget$extDateFormat <- "%a %b %d %Y %H:%M:%S"
+    
+    if(text != "") {
+      tmp <- as.Date(text, widget$..format)
+      if(!is.na(tmp))
+        text <- format(tmp, widget$extDateFormat)
+    }
+    
+    widget$setValue(value=text)           # no day
     widget$getValueJSMethod <- "getValue"
     widget$transportSignal <- c("change")
     ## coerceValues calls ..format
+
     widget$coerceValues <- function(., value) {
       ## Wed Jun 11 2008 00:00:00 GMT-0400 (EDT) -- ext format
-      theDate = as.Date(value,"%a %b %d %Y %H:%M:%S")
+      theDate = as.Date(value,.$extDateFormat)
       return(format(theDate,.$..format))
     }
       
@@ -23,8 +30,14 @@ gcalendar <- function(text = "", format = "%Y-%m-%d",
     ## override writeConstructor of show method
     widget$writeConstructor <- function(.) {
       lst <- list(xtype = "datefield",
-                  emptyText = .$..text,
                   id =  as.character(String(.$ID) + "date"))
+      if(is.na(.$getValue()) || .$getValue() == "") {
+        lst['emptyText'] <- "Select a date..."
+      } else {
+        lst['emptyText'] <- format(as.Date(.$..data, .$extDateFormat),"%m/%d/%Y")
+        lst['value'] <- String('new Date("') + .$..data +'")'#.$..text,
+      }
+
 
       ## size doesn't work here, as we the style thing isn't
       ## applied to 
